from pydantic_settings import BaseSettings, SettingsConfigDict

from src.constants import PydanticEnvPrefixEnum, EnvFileLocation, EnvironmentEnum

from src.settings.database import DatabaseSettings
from src.settings.gemini import GeminiSettings
from src.settings.rabbitmq import RabbitmqSettings


class Settings(BaseSettings):
    model_config = SettingsConfigDict(
        case_sensitive=True,
        env_nested_delimiter='__',
        env_prefix=PydanticEnvPrefixEnum.APP.value,
        env_file=(
            EnvFileLocation.PRODUCTION,
            # EnvFileLocation.TESTING,
        )
    )

    MODE: EnvironmentEnum

    POSTGRES: DatabaseSettings

    GEMINI: GeminiSettings
    RABBIT: RabbitmqSettings


settings = Settings() # type:ignore