from datetime import datetime
from typing import TYPE_CHECKING
from uuid import UUID

from sqlalchemy import ForeignKey, UniqueConstraint
from sqlalchemy.orm import Mapped, mapped_column, relationship

from src.core.database import Base

if TYPE_CHECKING:
    from src.core.database import TgChat, User, Success


class TgMessage(Base):
    __tablename__ = 'tg_messages'

    text: Mapped[str]
    message_time: Mapped[datetime]
    user_id: Mapped[int] = mapped_column(
        ForeignKey("users.id"),
    )
    chat_id: Mapped[int] = mapped_column(
        ForeignKey("tgchats.id"),
    )

    slice_id: Mapped[UUID]

    chat_relationship: Mapped["TgChat"] = relationship(
        back_populates="message_relationship"
    )
    user_relationship: Mapped["User"] = relationship(
        backref="message_relationship"
    )

    __table_args__ = (
        UniqueConstraint('chat_id', 'id', name='_chat_id_message_unq'),
    )
