import asyncio

from src.core.settings.base import settings
from src.core.tg_service.constants import TELETHON_CHAT_TYPES
from src.core.tg_service.schemas import MessageFromChatSchema
from src.core.tg_service.service import check_user_exists, check_chat_exists, check_chunk_state_and_publish
from src.core.tg_service import utils as api_tg_utils
from src.telethon_client import telethon_client

from telethon.events import NewMessage
from telethon.types import Message, User, Chat, Channel

DATA: dict[int, list[MessageFromChatSchema]] = dict()


lock = asyncio.Lock()


@telethon_client.on(event=NewMessage)
async def message_listener(event: NewMessage.Event) -> None:
    print("received new message")
    message: Message = event.message
    sender: User = await event.get_sender()
    chat: TELETHON_CHAT_TYPES = await event.get_chat()

    chat_type, chat_username = api_tg_utils.handle_chat_type(chat)
    if api_tg_utils.check_message_condition(
            message=message,
            sender=sender,
            chat_type=chat_type,
    ):
        async with lock:
            await check_user_exists(
                username=sender.username,
                first_name=sender.first_name,
                last_name=sender.last_name,
                user_id=sender.id,
            )

            await check_chat_exists(
                chat_id=chat.id,
                chat_type=chat_type.value,
                chat_title=chat.title,
                chat_username=chat_username,
            )

        message_schema = MessageFromChatSchema(
            id=message.id,
            user_id=sender.id,
            chat_id=chat.id,
            text=message.text,
            message_time=message.date,
        )
        await check_chunk_state_and_publish(
            data=DATA,
            message_schema=message_schema,
            chat_id=chat.id,
        )
