import emoji

# from telethon.events import NewMessage
from telethon.tl.types import Message, User as UserTelethon, Chat, Channel



from src.core.database import TgMessage, User, TgChat

from src.core.tg_service.constants import TELETHON_CHAT_TYPES, CustomChatTypes


def check_message_condition(
        message: Message,
        sender: User,
        chat_type: CustomChatTypes,
) -> bool:
    if isinstance(sender, Channel):
        return False

    if chat_type == CustomChatTypes.PRIVATE_GROUP:
        return False

    if not message.text:
        return False

    if sender.username:
        if 'bot' in sender.username.lower():
            return False

    emoji_count = emoji.emoji_count(str(message.text))
    if emoji_count > 3:
        return False

    return True



def create_and_format_message(
        reason: str,
        chat: TgChat,
        user_model: User | Channel,
) -> str:
    def escape_markdown_v2(text: str) -> str:
        if not text:
            return ""
        escape_chars = '_*[]()~`>#+-=|{}.!'
        return ''.join('\\' + char if char in escape_chars else char for char in text)

    def validate_markdown(text: str) -> str:
        """Ensure all markdown entities are properly closed"""
        # Count backticks to ensure pairs
        backtick_count = text.count('`')
        if backtick_count % 3 != 0:  # Code blocks use triple backticks
            # Remove unpaired backticks
            text = text.replace('`', 'ʻ')  # Replace with similar-looking character
        return text

    # User info
    username = escape_markdown_v2(user_model.username) if user_model.username else f"ID: {user_model.id}"
    user_link = f"[{username}](tg://user?id={user_model.id})" if user_model.username else f"ID: {user_model.id}"

    # Chat info
    chat_title = escape_markdown_v2(chat.title)

    if chat.username:
        chat_link = f"https://t.me/{chat.username}"
    else:
        chat_link = (
            f"https://t.me/c/{str(chat.id)[4:]}"
            if str(chat.id).startswith("-100")
            else f"Chat ID: {chat.id}"
        )

    # Escape reason
    reason_escaped = escape_markdown_v2(reason)

    # Header
    full_message = (
        f"🔥 *Найдена успешка!*\n"
        f"👤 *Пользователь:* {user_link}\n"
        f"🐩 *Чат:* [{chat_title}]({chat_link})\n"
        f"📌 *Причина:* {reason_escaped}\n\n"
        f"📝 *Диалог:*\n"
    )

    MAX_LENGTH = 4096


    # Final validation and truncation if needed
    full_message = validate_markdown(full_message)
    if len(full_message) > MAX_LENGTH:
        full_message = full_message[:MAX_LENGTH - 30].rsplit('\n', 2)[0] + "\n```\n...\n```\n_... сообщение обрезано ..._"

    return full_message


def handle_chat_type(
        chat: TELETHON_CHAT_TYPES
) -> tuple[CustomChatTypes, str | None]:
    chat_username = None
    if isinstance(chat, UserTelethon):
        chat_type = CustomChatTypes.PRIVATE_GROUP
    elif isinstance(chat, Chat):
        chat_type = CustomChatTypes.STANDARD_GROUP
    elif isinstance(chat, Channel):
        chat_username = chat.username
        if chat.megagroup:
            chat_type = CustomChatTypes.SUPERGROUP
        else:
            chat_type = CustomChatTypes.BROADCAST_CHANNEL
    else:
        raise ValueError(f"Invalid chat type check it!{chat}")

    return chat_type, chat_username