from typing import Annotated

from sqlalchemy.ext.asyncio import AsyncSession

from faststream import Depends

from src.core.database import User, TgChat
from src.core.tg_service.notify_success import notify_for_success
from src.core.workers.schemas import ResponseFromGeminiSchema, SuccessChatFromAiSchema
from src.core.database.connect import db_helper
from src.core.rabbitmq.connect import success_gemini_subscriber
from src.core.workers import crud as workers_crud


@success_gemini_subscriber
async def create_success_record(
        message: ResponseFromGeminiSchema,
        session: Annotated[AsyncSession, Depends(db_helper.get_async_session)],
):
        await workers_crud.bulk_create_success_reasons(
            success_schema=message,
            session=session,
        )
        for success_message in message.success:
            messages = await workers_crud.get_messages_by_slice_id_and_user_id(
                session=session,
                slice_id=success_message.slice_id,
                user_id=success_message.user_id
            )
            user_model = await session.get(User, success_message.user_id)
            chat_model = await session.get(TgChat, messages[0].chat_id)

            await notify_for_success(
                messages=messages,
                chat=chat_model, # type:ignore
                user_model=user_model, # type:ignore
                success_reason=success_message.reason, # type:ignore
            )






